@@ -16,6 +16,7 @@ class Heroku(cl1.CLI):
 				"--tail":"Tail the heroku website logs.",
 				"--add-env-variable MY_VARIABLE='helloworld' / --file /path/to/dict.json":"Add env variables to heroku.",
 				"--remove-env-variable MY_VARIABLE":"Remove env variables from heroku.",
+				"--get-env-variable MY_VARIABLE":"Get the specfied env variables from heroku.",
 				"-h / --help":"Show the documentation.",
 			},
 			options={},
@@ -51,9 +52,15 @@ class Heroku(cl1.CLI):
 				self.remove_environment_variables({
 					key: ""
 				})
+		elif '--get-env-variable' in sys.argv:
+			keys = self.get_argument("--get-env-variable")
+			i = {}
+			for key in keys.split(","):
+				i[key] = ""
+			self.get_environment_variables(i)
 		else:
 			print(self.documentation)
-			print("Selected an invalid mode.", mode="warning")
+			print("Selected an invalid mode.")
 	def check(self):
 		os.system("cd "+self.package.file_path.path)
 		os.system("heroku ps:scale web=1")
